@@ -1,6 +1,7 @@
 from mikro.schema import Representation
 from mikroj.registries.helper import BaseImageJHelper, set_running_helper
 import dask
+import xarray as xr
 
 class ImageJHelper(BaseImageJHelper):
 
@@ -9,6 +10,16 @@ class ImageJHelper(BaseImageJHelper):
         super().__init__(headless=headless, version=version, plugins= plugins)
 
 
+    def show_xarray(self, xarray: xr.DataArray):
+        if dask.is_dask_collection(xarray.data):
+            jimage = self.py.to_java(xarray.compute())
+        else:
+            jimage = self.py.to_java(xarray)
+        
+        self.ui.show(xarray.name, jimage)
+
+
+
     def displayRep(self, rep: Representation):
         image = rep.data.squeeze()
 
